/*---------------------------------------------------------------------------*/
/* GIVE-CLI.C -- CLI routines for GIVE.C                                     */
/*---------------------------------------------------------------------------*/


#include <clidef.h>
#include <descrip.h>
#include <ssdef.h>
#include <climsgdef.h>

#include "give.h"
#include "give-cli.h"
#include "give-str.h"

/*---------------------------------------------------------------------------*/
/* Get_Presence -- this function checks for the presence of a command        */
/*   element and sets the boolean variable isthere to true if the element    */
/*   is present in the command line, false if not.                           */

void Get_Presence( char *entity, boolean *isthere ) {

   ulong ss_stat;
   $DESCRIPTOR_Z( entity_d, entity );

   ss_stat = cli$present( &entity_d );
   if( ss_failure( ss_stat ) || (ss_stat==CLI$_NEGATED) ||
                                (ss_stat==CLI$_ABSENT)    )
      *isthere = FALSE;
   else
      *isthere = TRUE;
}

/*---------------------------------------------------------------------------*/
/* Get_Value -- this function gets the value of an entity, if any, from a    */
/*   command string and returns it in the string value.  If the command      */
/*   entity is not present in the string, a null string is returned.         */

void Get_Value( char *entity, char *value, ushort max_value_length ) {

   ulong ss_stat;
   boolean entity_present;
   ushort value_length;
   $DESCRIPTOR_Z( entity_d, entity );
   $DESCRIPTOR_L( value_d, value, max_value_length );

   Get_Presence( entity, &entity_present );
   if( !entity_present ) {
      value[0] = '\0';
   } else {
      ss_stat = cli$get_value( &entity_d, &value_d, &value_length );
      if( ss_failure( ss_stat ) )
         value[0] = '\0';
      else
         value[value_length] = '\0';
   }
}

/*---------------------------------------------------------------------------*/
/* Get_List -- this function gets a list of entities and allocates an array  */
/* for them.                                                                 */

ulong Get_List( char *entity, char **value, ushort max_value_length )
{
   ulong ss_stat;
   ulong i;
   char *temp_hold_value;

   if( (temp_hold_value = malloc( max_value_length+1 ))==NULL )
      return( GIVE_CLI_MEMERR );

   for( i=0;; i++ ) {
      Get_Value( entity, temp_hold_value, max_value_length );
      if( (value[i] = strdup( temp_hold_value ))==NULL )
         return( GIVE_CLI_MEMERR );
      if( temp_hold_value[0] == '\0' )
         break;
   }
   

   return( SS$_NORMAL );
}
